# datadivr

[![Release](https://img.shields.io/github/v/release/menchelab/datadivr)](https://img.shields.io/github/v/release/menchelab/datadivr)
[![Build status](https://img.shields.io/github/actions/workflow/status/menchelab/datadivr/main.yml?branch=main)](https://github.com/menchelab/datadivr/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/menchelab/datadivr/branch/main/graph/badge.svg)](https://codecov.io/gh/menchelab/datadivr)
[![Commit activity](https://img.shields.io/github/commit-activity/m/menchelab/datadivr)](https://img.shields.io/github/commit-activity/m/menchelab/datadivr)
[![License](https://img.shields.io/github/license/menchelab/datadivr)](https://img.shields.io/github/license/menchelab/datadivr)

datadivr backend and toolset.

- **Github repository**: <https://github.com/menchelab/datadivr/>
- **Documentation** <https://menchelab.github.io/datadivr/>
- **Contributing** <https://menchelab.github.io/datadivr/contributing/>
